@@ -22,6 +22,7 @@ from .editable_combo_box import EditableComboBox
 from .shrunk_push_button import ShrunkPushButton, VShrunkPushButton
 from .tool_window import ToolWindow
 from .combo_box import ComboBox, BindableComboBox, typed_bindable_combo_box
+from .steppable_combo_box import SteppableComboBox
 from .linkable import LinkableWidget
 from .datetime import DateTimeEdit
 from .line_edit import LineEdit, BindableLineEdit
@@ -46,3 +47,4 @@ from .styleable import make_styleable
 from .popout import PopoutWidget
 from .popup import Popup
 from .delegates import ComboBoxItemDelegate, DateTimeItemDelegate, BulkValueSelectorItemDelegate
+from .labelled import make_labelled
